pub struct ProtocolVersionsCache {
pub global_cache: IntMap<ProtocolVersion, u64>,
/* private fields */
}Expand description
ProtocolVersion cache that handles both global and block data
Fields
global_cache: IntMap<ProtocolVersion, u64>The current global cache for protocol versions
Implementations
Sourceimpl ProtocolVersionsCache
impl ProtocolVersionsCache
Sourcepub fn load_if_needed(
&mut self,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_version: &DriveVersion,
) -> Result<(), Error>
pub fn load_if_needed( &mut self, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_version: &DriveVersion, ) -> Result<(), Error>
Load the protocol versions cache from disk if needed
Sourcepub fn set_block_cache_version_count(
&mut self,
version: ProtocolVersion,
count: u64,
)
pub fn set_block_cache_version_count( &mut self, version: ProtocolVersion, count: u64, )
Sets the protocol version to the block cache
Sourcepub fn get(&self, version: &ProtocolVersion) -> Result<Option<&u64>, Error>
pub fn get(&self, version: &ProtocolVersion) -> Result<Option<&u64>, Error>
Tries to get a version from block cache if present if block cache doesn’t have the version set then it tries get the version from global cache
Sourcepub fn block_global_cache(&mut self)
pub fn block_global_cache(&mut self)
Disable the global cache to do not allow get counters If global cache is blocked then [get] will return an error
Sourcepub fn unblock_global_cache(&mut self)
pub fn unblock_global_cache(&mut self)
Unblock the global cache This function enables the normal behaviour of [get] function
Sourcepub fn merge_block_cache(&mut self)
pub fn merge_block_cache(&mut self)
Merge block cache to global cache
Sourcepub fn clear_global_cache(&mut self)
pub fn clear_global_cache(&mut self)
Clears the global cache
Sourcepub fn clear_block_cache(&mut self)
pub fn clear_block_cache(&mut self)
Clear block cache
Sourcepub fn versions_passing_threshold(
&self,
required_upgraded_hpmns: u64,
) -> Vec<ProtocolVersion> ⓘ
pub fn versions_passing_threshold( &self, required_upgraded_hpmns: u64, ) -> Vec<ProtocolVersion> ⓘ
Collect versions passing threshold