ResourceVoteChoiceToKeyTrait

Trait ResourceVoteChoiceToKeyTrait 

pub trait ResourceVoteChoiceToKeyTrait {
    // Required method
    fn to_key(&self) -> Vec<u8> ;
}
A helper trait to get the key for a resource vote

Required Methods

fn to_key(&self) -> Vec<u8>

A helper function to get the key for a resource vote

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ResourceVoteChoiceToKeyTrait for ResourceVoteChoice

Source

fn to_key(&self) -> Vec<u8>

Implementors