pub enum ProofError {
Show 14 variants
TooManyElements(&'static str),
WrongElementCount {
expected: usize,
got: usize,
},
Overflow(&'static str),
CorruptedProof(String),
IncorrectProof(String),
UnexpectedResultProof(String),
InvalidTransition(String),
UnknownContract(String),
InvalidMetadata(String),
ErrorRetrievingContract(String),
MissingContextRequirement(String),
IncompleteProof(&'static str),
IncorrectValueSize(&'static str),
IncorrectElementPath {
expected: Path,
actual: Path,
},
}Expand description
Proof errors
Variants
TooManyElements(&'static str)
Too many elements error
WrongElementCount
Wrong element count error
Overflow(&'static str)
Overflow error
CorruptedProof(String)
An incoherent result is akin to a corrupted code execution, the proof returned is said to be valid, however data it possesses isn’t what was asked for.
IncorrectProof(String)
The proof returned is said to be valid, data is what we asked for, but is not what was expected, for example if we updated a contract, but we are getting back the old contract
UnexpectedResultProof(String)
The proof returned is said to be valid, data is what we asked for, but is not what was expected, for example we ask for token balance, and we get that the token does not exist. UnexpectedResultProof is most likely is a User error. IncorrectProof is most likely a system error.
InvalidTransition(String)
The transition we are trying to prove was executed is invalid
UnknownContract(String)
The transition we are trying to prove has an unknown contract
InvalidMetadata(String)
The metadata we got back from platform is incorrect
ErrorRetrievingContract(String)
We are trying to callback to retrieve a contract, but there was an error
MissingContextRequirement(String)
We are missing a context requirement
IncompleteProof(&'static str)
Incomplete proof error
IncorrectValueSize(&'static str)
Incorrect value size
IncorrectElementPath
Incorrect element path error