LowLevelDriveOperationTreeTypeConverter

Trait LowLevelDriveOperationTreeTypeConverter 

pub trait LowLevelDriveOperationTreeTypeConverter {
    // Required method
    fn empty_tree_operation_for_known_path_key(
        &self,
        path: Vec<Vec<u8>>,
        key: Vec<u8>,
        storage_flags: Option<&StorageFlags>,
    ) -> Result<LowLevelDriveOperation, Error>;
}
A trait for getting an empty tree operation based on the tree type

Required Methods

fn empty_tree_operation_for_known_path_key( &self, path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Result<LowLevelDriveOperation, Error>

Sets GroveOperation for inserting an empty tree at the given path and key

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LowLevelDriveOperationTreeTypeConverter for TreeType

Source

fn empty_tree_operation_for_known_path_key( &self, path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Result<LowLevelDriveOperation, Error>

Sets GroveOperation for inserting an empty tree at the given path and key

Implementors