pub enum WhereOperator {
Equal,
GreaterThan,
GreaterThanOrEquals,
LessThan,
LessThanOrEquals,
Between,
BetweenExcludeBounds,
BetweenExcludeLeft,
BetweenExcludeRight,
In,
StartsWith,
}Expand description
Where operator arguments
Variants
Equal
Equal
GreaterThan
Greater than
GreaterThanOrEquals
Greater than or equal
LessThan
Less than
LessThanOrEquals
Less than or equal
Between
Between
BetweenExcludeBounds
Between excluding bounds
BetweenExcludeLeft
Between excluding left bound
BetweenExcludeRight
Between excluding right bound
In
In
StartsWith
Starts with
Implementations
Sourceimpl WhereOperator
impl WhereOperator
Sourcepub fn allows_flip(&self) -> bool
pub fn allows_flip(&self) -> bool
Matches the where operator argument and returns true if it allows flip function
Sourcepub fn flip(&self) -> Result<WhereOperator, Error>
pub fn flip(&self) -> Result<WhereOperator, Error>
Flips the where operator
Sourceimpl WhereOperator
impl WhereOperator
Sourcepub fn eval(&self, left_value: &Value, right_value: &Value) -> bool
pub fn eval(&self, left_value: &Value, right_value: &Value) -> bool
Shared operator evaluator for both WhereClause and ValueClause
Sourcepub fn value_shape_ok(
&self,
value: &Value,
property_type: &DocumentPropertyType,
) -> bool
pub fn value_shape_ok( &self, value: &Value, property_type: &DocumentPropertyType, ) -> bool
Validates that a value matches the expected shape for this operator and property type