pub struct WhereClause {
pub field: String,
pub operator: WhereOperator,
pub value: Value,
}Expand description
Where clause struct
Fields
field: StringField
operator: WhereOperatorOperator
value: ValueValue
Implementations
Sourceimpl<'a> WhereClause
impl<'a> WhereClause
Sourcepub fn is_identifier(&self) -> bool
pub fn is_identifier(&self) -> bool
Returns true if the WhereClause is an identifier
Sourcepub fn in_values(&self) -> QuerySyntaxValidationResult<Cow<'_, Vec<Value>>>
pub fn in_values(&self) -> QuerySyntaxValidationResult<Cow<'_, Vec<Value>>>
Returns the where clause in values if they are an array of values, else an error
Sourcepub fn less_than(&self, other: &Self, allow_eq: bool) -> Result<bool, Error>
pub fn less_than(&self, other: &Self, allow_eq: bool) -> Result<bool, Error>
Returns true if the less than where clause is true
Sourcepub fn from_components(clause_components: &'a [Value]) -> Result<Self, Error>
pub fn from_components(clause_components: &'a [Value]) -> Result<Self, Error>
Returns a WhereClause given a list of clause components
Sourcepub fn matches_value(&self, value: &Value) -> bool
pub fn matches_value(&self, value: &Value) -> bool
Evaluate this WhereClause against a provided Value
Sourcepub fn validate_against_schema(
&self,
document_type: DocumentTypeRef<'_>,
) -> QuerySyntaxSimpleValidationResult
pub fn validate_against_schema( &self, document_type: DocumentTypeRef<'_>, ) -> QuerySyntaxSimpleValidationResult
Validate this where clause against the document schema