present_entries_on_axis

Function present_entries_on_axis 

pub fn present_entries_on_axis(
    axis: RankedAxis,
    entries: Vec<RankedEntry>,
) -> Vec<RankedEntry>
Entries read on read_axis_for’s axis, presented on the requested axis: document counts read from sums come back as counts. A no-op whenever the read axis is the requested one.