Enum GroveError
pub enum GroveError {
Show 41 variants
Infallible,
CyclicReference,
ReferenceLimit,
MissingReference(String),
InternalError(String),
InvalidProof(PathQuery, String),
InvalidInput(&'static str),
PathKeyNotFound(String),
PathNotFound(String),
PathParentLayerNotFound(String),
CorruptedReferencePathKeyNotFound(String),
CorruptedReferencePathNotFound(String),
CorruptedReferencePathParentLayerNotFound(String),
InvalidParentLayerPath(String),
InvalidPath(String),
CorruptedPath(String),
InvalidQuery(&'static str),
MissingParameter(&'static str),
InvalidParameter(&'static str),
StorageError(Error),
CorruptedData(String),
CorruptedStorage(String),
InvalidCodeExecution(&'static str),
CorruptedCodeExecution(&'static str),
InvalidBatchOperation(&'static str),
DeleteUpTreeStopHeightMoreThanInitialPathSize(String),
DeletingNonEmptyTree(&'static str),
ClearingTreeWithSubtreesNotAllowed(&'static str),
JustInTimeElementFlagsClientError(String),
SplitRemovalBytesClientError(String),
ClientReturnedNonClientError(String),
OverrideNotAllowed(&'static str),
PathNotFoundInCacheForEstimatedCosts(String),
NotSupported(String),
MerkError(Error),
VersionError(GroveVersionError),
ElementError(ElementError),
QueryError(Error),
CyclicError(&'static str),
Overflow(&'static str),
CommitmentTreeError(String),
}Expand description
GroveDB Errors
Variants
Infallible
This error can not happen, used for generics
CyclicReference
Cyclic reference
ReferenceLimit
Reference limit
MissingReference(String)
Missing reference
InternalError(String)
Internal error
InvalidProof(PathQuery, String)
Invalid proof
InvalidInput(&'static str)
Invalid input
PathKeyNotFound(String)
The path key not found could represent a valid query, just where the path key isn’t there
PathNotFound(String)
The path not found could represent a valid query, just where the path isn’t there
PathParentLayerNotFound(String)
The path not found could represent a valid query, just where the parent path merk isn’t there
CorruptedReferencePathKeyNotFound(String)
The path’s item by key referenced was not found
CorruptedReferencePathNotFound(String)
The path referenced was not found
CorruptedReferencePathParentLayerNotFound(String)
The path’s parent merk wasn’t found
InvalidParentLayerPath(String)
The invalid parent layer path represents a logical error from the client library
InvalidPath(String)
The invalid path represents a logical error from the client library
CorruptedPath(String)
The corrupted path represents a consistency error in internal groveDB logic
InvalidQuery(&'static str)
Invalid query
MissingParameter(&'static str)
Missing parameter
InvalidParameter(&'static str)
Invalid parameter
StorageError(Error)
Storage error
CorruptedData(String)
Corrupted data
CorruptedStorage(String)
Corrupted storage
InvalidCodeExecution(&'static str)
Invalid code execution
CorruptedCodeExecution(&'static str)
Corrupted code execution
InvalidBatchOperation(&'static str)
Invalid batch operation
DeleteUpTreeStopHeightMoreThanInitialPathSize(String)
Delete up tree stop height more than initial path size
DeletingNonEmptyTree(&'static str)
Deleting non empty tree
ClearingTreeWithSubtreesNotAllowed(&'static str)
Clearing tree with subtrees not allowed
JustInTimeElementFlagsClientError(String)
Just in time element flags client error
SplitRemovalBytesClientError(String)
Split removal bytes client error
ClientReturnedNonClientError(String)
Client returned non client error
OverrideNotAllowed(&'static str)
Override not allowed
PathNotFoundInCacheForEstimatedCosts(String)
Path not found in cache for estimated costs
NotSupported(String)
Not supported
MerkError(Error)
Merk error
VersionError(GroveVersionError)
Version error
ElementError(ElementError)
Element error
QueryError(Error)
Query error
CyclicError(&'static str)
Cyclic reference
Overflow(&'static str)
Overflow error
CommitmentTreeError(String)
Commitment tree operation error
Implementations
impl Error
impl Error
pub fn add_context(&mut self, append: impl AsRef<str>)
pub fn add_context(&mut self, append: impl AsRef<str>)
Appends additional context to the error message.