Struct QueryResultElements
pub struct QueryResultElements {
pub elements: Vec<QueryResultElement>,
}Expand description
Query result elements
Fields
elements: Vec<QueryResultElement>Elements
Implementations
impl QueryResultElements
impl QueryResultElements
pub fn new() -> QueryResultElements
pub fn new() -> QueryResultElements
New
pub fn from_elements(elements: Vec<QueryResultElement>) -> QueryResultElements
pub fn from_elements(elements: Vec<QueryResultElement>) -> QueryResultElements
From elements
pub fn into_iterator(self) -> IntoIter<QueryResultElement>
pub fn into_iterator(self) -> IntoIter<QueryResultElement>
Into iterator
pub fn to_elements(self) -> Vec<Element>
pub fn to_elements(self) -> Vec<Element>
To elements
pub fn to_key_elements(self) -> Vec<(Vec<u8>, Element)>
pub fn to_key_elements(self) -> Vec<(Vec<u8>, Element)>
To key elements
pub fn to_key_elements_btree_map(self) -> BTreeMap<Vec<u8>, Element>
pub fn to_key_elements_btree_map(self) -> BTreeMap<Vec<u8>, Element>
To key elements btree map
pub fn to_key_elements_hash_map(self) -> HashMap<Vec<u8>, Element>
pub fn to_key_elements_hash_map(self) -> HashMap<Vec<u8>, Element>
To key elements hash map
pub fn to_path_key_elements_btree_map(
self,
) -> BTreeMap<(Vec<Vec<u8>>, Vec<u8>), Element>
pub fn to_path_key_elements_btree_map( self, ) -> BTreeMap<(Vec<Vec<u8>>, Vec<u8>), Element>
To path key elements btree map
pub fn to_last_path_to_keys_btree_map(self) -> BTreeMap<Vec<u8>, Vec<Vec<u8>>>
pub fn to_last_path_to_keys_btree_map(self) -> BTreeMap<Vec<u8>, Vec<Vec<u8>>>
To last path to keys btree map This is useful if for example the element is a sum item and isn’t important Used in Platform Drive for getting voters for multiple contenders
pub fn to_path_to_key_elements_btree_map(
self,
) -> BTreeMap<Vec<Vec<u8>>, BTreeMap<Vec<u8>, Element>>
pub fn to_path_to_key_elements_btree_map( self, ) -> BTreeMap<Vec<Vec<u8>>, BTreeMap<Vec<u8>, Element>>
To path to key, elements btree map
pub fn to_last_path_to_key_elements_btree_map(
self,
) -> BTreeMap<Vec<u8>, BTreeMap<Vec<u8>, Element>>
pub fn to_last_path_to_key_elements_btree_map( self, ) -> BTreeMap<Vec<u8>, BTreeMap<Vec<u8>, Element>>
To last path to key, elements btree map
pub fn to_last_path_to_elements_btree_map(
self,
) -> BTreeMap<Vec<u8>, Vec<Element>>
pub fn to_last_path_to_elements_btree_map( self, ) -> BTreeMap<Vec<u8>, Vec<Element>>
To last path to elements btree map This is useful if the key is not import
pub fn to_btree_map_level_results(self) -> BTreeMapLevelResult
pub fn to_btree_map_level_results(self) -> BTreeMapLevelResult
To last path to elements btree map This is useful if the key is not import