pub struct SingleDocumentDriveQuery {
pub contract_id: [u8; 32],
pub document_type_name: String,
pub document_type_keeps_history: bool,
pub document_id: [u8; 32],
pub block_time_ms: Option<u64>,
pub contested_status: SingleDocumentDriveQueryContestedStatus,
}Expand description
Drive query struct
Fields
contract_id: [u8; 32]DataContract
document_type_name: StringDocument type
document_type_keeps_history: boolDocument type keeps history
document_id: [u8; 32]Document
block_time_ms: Option<u64>Block time
contested_status: SingleDocumentDriveQueryContestedStatusTrue if the document might have gone to a contested resolution
Implementations
Sourceimpl SingleDocumentDriveQuery
impl SingleDocumentDriveQuery
Sourcepub fn construct_path_query(
&self,
platform_version: &PlatformVersion,
) -> Result<PathQuery, Error>
pub fn construct_path_query( &self, platform_version: &PlatformVersion, ) -> Result<PathQuery, Error>
Operations to construct a path query.
Sourceimpl SingleDocumentDriveQuery
impl SingleDocumentDriveQuery
Sourcepub fn verify_proof(
&self,
is_subset: bool,
proof: &[u8],
document_type: DocumentTypeRef<'_>,
platform_version: &PlatformVersion,
) -> Result<(RootHash, Option<Document>), Error>
pub fn verify_proof( &self, is_subset: bool, proof: &[u8], document_type: DocumentTypeRef<'_>, platform_version: &PlatformVersion, ) -> Result<(RootHash, Option<Document>), Error>
Verifies the proof of a single document query.
is_subset indicates if the function should verify a subset of a larger proof.
Parameters
is_subset: A boolean indicating whether to verify a subset of a larger proof.proof: A byte slice representing the proof to be verified.document_type: The type of the document being verified.platform_version: The platform version against which to verify the proof.
Returns
Returns a Result with a tuple of RootHash and Option<Document>. The Option<Document>
represents the deserialized document if it exists.
Errors
Returns an Error if:
- An unknown or unsupported platform version is provided.
- Any other error as documented in the specific versioned function.
Sourceimpl SingleDocumentDriveQuery
impl SingleDocumentDriveQuery
Sourcepub fn verify_proof_keep_serialized(
&self,
is_subset: bool,
proof: &[u8],
platform_version: &PlatformVersion,
) -> Result<(RootHash, Option<Vec<u8>>), Error>
pub fn verify_proof_keep_serialized( &self, is_subset: bool, proof: &[u8], platform_version: &PlatformVersion, ) -> Result<(RootHash, Option<Vec<u8>>), Error>
Verifies the proof of a document while keeping it serialized.
is_subset indicates if the function should verify a subset of a larger proof.
Parameters
is_subset: A boolean indicating whether to verify a subset of a larger proof.proof: A byte slice representing the proof to be verified.platform_version: The platform version against which to verify the proof.
Returns
Returns a Result with a tuple of RootHash and Option<Vec<u8>>. The Option<Vec<u8>>
represents the serialized document if it exists.
Errors
Returns an Error if:
- An unknown or unsupported platform version is provided.
- Any other error as documented in the specific versioned function.