pub type ContractLookupFn<'a> = dyn Fn(&Identifier) -> Result<Option<Arc<DataContract>>, Error> + 'a;Expand description
Function type for looking up a contract by identifier
This function is used to look up a contract by its identifier. It should be implemented by the caller in order to provide data contract required for operations like proof verification.