pub struct ContestedDocumentVotePollDriveQuery {
pub vote_poll: ContestedDocumentResourceVotePoll,
pub result_type: ContestedDocumentVotePollDriveQueryResultType,
pub offset: Option<u16>,
pub limit: Option<u16>,
pub start_at: Option<([u8; 32], bool)>,
pub allow_include_locked_and_abstaining_vote_tally: bool,
}Expand description
Vote Poll Drive Query struct
Fields
vote_poll: ContestedDocumentResourceVotePollWhat vote poll are we asking for?
result_type: ContestedDocumentVotePollDriveQueryResultTypeWhat result type are we interested in
offset: Option<u16>Offset
limit: Option<u16>Limit for returned contestant info, including locked or abstaining votes does not change this
start_at: Option<([u8; 32], bool)>Start at identity id
allow_include_locked_and_abstaining_vote_tally: boolInclude locked and abstaining vote tally This is not automatic, it will just be at the beginning if the order is ascending If the order is descending, we will get a value if we finish the query
Implementations
Sourceimpl ContestedDocumentVotePollDriveQuery
impl ContestedDocumentVotePollDriveQuery
Sourcepub fn resolve(
&self,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'_>, Error>
pub fn resolve( &self, drive: &Drive, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'_>, Error>
Resolves the contested document vote poll drive query.
This method processes the query by interacting with the drive, using the provided transaction and platform version to ensure consistency and compatibility.
Parameters
drive: A reference to theDriveobject used for database interactions.transaction: The transaction argument used to ensure consistency during the resolve operation.platform_version: The platform version to ensure compatibility.
Returns
Ok(ResolvedContestedDocumentVotePollDriveQuery)- The resolved query information.Err(Error)- An error if the resolution process fails.
Errors
This method returns an Error variant if there is an issue resolving the query.
The specific error depends on the underlying problem encountered during resolution.
Sourcepub fn resolve_with_known_contracts_provider<'a>(
&self,
known_contracts_provider_fn: &ContractLookupFn<'_>,
) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'a>, Error>
pub fn resolve_with_known_contracts_provider<'a>( &self, known_contracts_provider_fn: &ContractLookupFn<'_>, ) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'a>, Error>
Resolves with a known contract provider
Sourcepub fn resolve_with_provided_borrowed_contract<'a>(
&self,
data_contract: &'a DataContract,
) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'a>, Error>
pub fn resolve_with_provided_borrowed_contract<'a>( &self, data_contract: &'a DataContract, ) -> Result<ResolvedContestedDocumentVotePollDriveQuery<'a>, Error>
Resolves with a provided borrowed contract
Sourcepub fn execute_with_proof(
self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(Vec<u8>, u64), Error>
pub fn execute_with_proof( self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(Vec<u8>, u64), Error>
Executes a query with proof and returns the items and fee.
Sourcepub fn execute_no_proof_with_cost(
&self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(ContestedDocumentVotePollDriveQueryExecutionResult, u64), Error>
pub fn execute_no_proof_with_cost( &self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(ContestedDocumentVotePollDriveQueryExecutionResult, u64), Error>
Executes a query with no proof and returns the items, skipped items, and fee.
Sourcepub fn execute_no_proof(
&self,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<ContestedDocumentVotePollDriveQueryExecutionResult, Error>
pub fn execute_no_proof( &self, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<ContestedDocumentVotePollDriveQueryExecutionResult, Error>
Executes an internal query with no proof and returns the values and skipped items.