pub struct ContestedDocumentVotePollDriveQueryExecutionResult {
pub contenders: Vec<ContenderWithSerializedDocument>,
pub locked_vote_tally: Option<u32>,
pub abstaining_vote_tally: Option<u32>,
pub winner: Option<(ContestedDocumentVotePollWinnerInfo, BlockInfo)>,
pub skipped: u16,
}Expand description
Represents the result of executing a contested document vote poll drive query.
This struct holds the list of contenders and the number of skipped items when an offset is given.
Fields
contenders: Vec<ContenderWithSerializedDocument>The list of contenders returned by the query.
locked_vote_tally: Option<u32>Locked tally
abstaining_vote_tally: Option<u32>Abstaining tally
winner: Option<(ContestedDocumentVotePollWinnerInfo, BlockInfo)>Finalization info
skipped: u16The number of skipped items when an offset is given.