pub trait DriveHighLevelOperationConverter {
// Required method
fn into_high_level_drive_operations<'a>(
self,
epoch: &Epoch,
platform_version: &PlatformVersion,
) -> Result<Vec<DriveOperation<'a>>, Error>;
}Expand description
A converter that will get High Level Drive Operations from State transitions
Required Methods
Sourcefn into_high_level_drive_operations<'a>(
self,
epoch: &Epoch,
platform_version: &PlatformVersion,
) -> Result<Vec<DriveOperation<'a>>, Error>
fn into_high_level_drive_operations<'a>( self, epoch: &Epoch, platform_version: &PlatformVersion, ) -> Result<Vec<DriveOperation<'a>>, Error>
This will get a list of atomic drive operations from a high level operations