pub enum DataContractCreateTransitionAction {
V0(DataContractCreateTransitionActionV0),
V1(DataContractCreateTransitionActionV1),
}Expand description
data contract create transition action
Variants
V0(DataContractCreateTransitionActionV0)
v0
V1(DataContractCreateTransitionActionV1)
v1: adds contract groups
Implementations
Sourceimpl DataContractCreateTransitionAction
impl DataContractCreateTransitionAction
Sourcepub fn try_from_transition(
value: DataContractCreateTransition,
block_info: &BlockInfo,
full_validation: bool,
validation_operations: &mut Vec<ProtocolValidationOperation>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn try_from_transition( value: DataContractCreateTransition, block_info: &BlockInfo, full_validation: bool, validation_operations: &mut Vec<ProtocolValidationOperation>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
tries to transform the DataContractCreateTransition into a DataContractCreateTransitionAction if validation is true the data contract transformation verifies that the data contract is valid if validation is false, the data contract base structure is created regardless of if it is valid
Sourcepub fn try_from_borrowed_transition(
value: &DataContractCreateTransition,
block_info: &BlockInfo,
full_validation: bool,
validation_operations: &mut Vec<ProtocolValidationOperation>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn try_from_borrowed_transition( value: &DataContractCreateTransition, block_info: &BlockInfo, full_validation: bool, validation_operations: &mut Vec<ProtocolValidationOperation>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
tries to transform the borrowed DataContractCreateTransition into a DataContractCreateTransitionAction if validation is true the data contract transformation verifies that the data contract is valid if validation is false, the data contract base structure is created regardless of if it is valid
Sourceimpl DataContractCreateTransitionAction
impl DataContractCreateTransitionAction
Sourcepub fn data_contract(self) -> DataContract
pub fn data_contract(self) -> DataContract
data contract
Sourcepub fn data_contract_ref(&self) -> &DataContract
pub fn data_contract_ref(&self) -> &DataContract
data contract ref
Sourcepub fn identity_nonce(&self) -> IdentityNonce
pub fn identity_nonce(&self) -> IdentityNonce
identity nonce
Sourcepub fn user_fee_increase(&self) -> UserFeeIncrease
pub fn user_fee_increase(&self) -> UserFeeIncrease
fee multiplier
Sourcepub fn contract_group(&self) -> Option<&(Identifier, ContractGroupInfo)>
pub fn contract_group(&self) -> Option<&(Identifier, ContractGroupInfo)>
The contract group the transition registers, with its derived id, if any.
Sourcepub fn contract_group_memberships(&self) -> &[ContractGroupMembership]
pub fn contract_group_memberships(&self) -> &[ContractGroupMembership]
The contract group memberships the created contract declares.