pub enum DataContractUpdateTransitionAction {
V0(DataContractUpdateTransitionActionV0),
}Expand description
data contract update transition action
Variants
Implementations
Sourceimpl DataContractUpdateTransitionAction
impl DataContractUpdateTransitionAction
Sourcepub fn try_from_transition(
value: DataContractUpdateTransition,
block_info: &BlockInfo,
full_validation: bool,
validation_operations: &mut Vec<ProtocolValidationOperation>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn try_from_transition( value: DataContractUpdateTransition, block_info: &BlockInfo, full_validation: bool, validation_operations: &mut Vec<ProtocolValidationOperation>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
tries to transform the DataContractUpdateTransition into a DataContractUpdateTransitionAction if validation is true the data contract transformation verifies that the data contract is valid if validation is false, the data contract base structure is created regardless of if it is valid
Sourcepub fn try_from_borrowed_transition(
value: &DataContractUpdateTransition,
block_info: &BlockInfo,
full_validation: bool,
validation_operations: &mut Vec<ProtocolValidationOperation>,
platform_version: &PlatformVersion,
) -> Result<Self, ProtocolError>
pub fn try_from_borrowed_transition( value: &DataContractUpdateTransition, block_info: &BlockInfo, full_validation: bool, validation_operations: &mut Vec<ProtocolValidationOperation>, platform_version: &PlatformVersion, ) -> Result<Self, ProtocolError>
tries to transform the borrowed DataContractUpdateTransition into a DataContractUpdateTransitionAction if validation is true the data contract transformation verifies that the data contract is valid if validation is false, the data contract base structure is created regardless of if it is valid
Sourceimpl DataContractUpdateTransitionAction
impl DataContractUpdateTransitionAction
Sourcepub fn data_contract(self) -> DataContract
pub fn data_contract(self) -> DataContract
data contract
Sourcepub fn data_contract_ref(&self) -> &DataContract
pub fn data_contract_ref(&self) -> &DataContract
data contract ref
Sourcepub fn data_contract_mut(&mut self) -> &mut DataContract
pub fn data_contract_mut(&mut self) -> &mut DataContract
data contract mut
Sourcepub fn identity_contract_nonce(&self) -> IdentityNonce
pub fn identity_contract_nonce(&self) -> IdentityNonce
identity contract nonce
Sourcepub fn user_fee_increase(&self) -> UserFeeIncrease
pub fn user_fee_increase(&self) -> UserFeeIncrease
fee multiplier