StateTransitionAction

Enum StateTransitionAction 

pub enum StateTransitionAction {
Show 24 variants DataContractCreateAction(DataContractCreateTransitionAction), DataContractUpdateAction(DataContractUpdateTransitionAction), BatchAction(BatchTransitionAction), IdentityCreateAction(IdentityCreateTransitionAction), IdentityCreateFromAddressesAction(IdentityCreateFromAddressesTransitionAction), IdentityTopUpAction(IdentityTopUpTransitionAction), IdentityTopUpFromAddressesAction(IdentityTopUpFromAddressesTransitionAction), IdentityCreditWithdrawalAction(IdentityCreditWithdrawalTransitionAction), IdentityUpdateAction(IdentityUpdateTransitionAction), IdentityCreditTransferAction(IdentityCreditTransferTransitionAction), IdentityCreditTransferToAddressesAction(IdentityCreditTransferToAddressesTransitionAction), AddressFundsTransfer(AddressFundsTransferTransitionAction), AddressCreditWithdrawal(AddressCreditWithdrawalTransitionAction), AddressFundingFromAssetLock(AddressFundingFromAssetLockTransitionAction), MasternodeVoteAction(MasternodeVoteTransitionAction), BumpIdentityNonceAction(BumpIdentityNonceAction), BumpIdentityDataContractNonceAction(BumpIdentityDataContractNonceAction), PartiallyUseAssetLockAction(PartiallyUseAssetLockAction), BumpAddressInputNoncesAction(BumpAddressInputNoncesAction), ShieldAction(ShieldTransitionAction), ShieldedTransferAction(ShieldedTransferTransitionAction), UnshieldAction(UnshieldTransitionAction), ShieldFromAssetLockAction(ShieldFromAssetLockTransitionAction), ShieldedWithdrawalAction(ShieldedWithdrawalTransitionAction),
}
ST action

Variants



DataContractCreateAction(DataContractCreateTransitionAction)

data contract create



DataContractUpdateAction(DataContractUpdateTransitionAction)

data contract update



BatchAction(BatchTransitionAction)

batch



IdentityCreateAction(IdentityCreateTransitionAction)

identity create



IdentityCreateFromAddressesAction(IdentityCreateFromAddressesTransitionAction)

identity create from addresses



IdentityTopUpAction(IdentityTopUpTransitionAction)

identity topup



IdentityTopUpFromAddressesAction(IdentityTopUpFromAddressesTransitionAction)

identity topup from addresses



IdentityCreditWithdrawalAction(IdentityCreditWithdrawalTransitionAction)

identity credit withdrawal



IdentityUpdateAction(IdentityUpdateTransitionAction)

identity update



IdentityCreditTransferAction(IdentityCreditTransferTransitionAction)

identity credit transfer



IdentityCreditTransferToAddressesAction(IdentityCreditTransferToAddressesTransitionAction)

identity credit transfer to addresses



AddressFundsTransfer(AddressFundsTransferTransitionAction)

address funds transfer



AddressCreditWithdrawal(AddressCreditWithdrawalTransitionAction)

address credit withdrawal



AddressFundingFromAssetLock(AddressFundingFromAssetLockTransitionAction)

address funding from asset lock



MasternodeVoteAction(MasternodeVoteTransitionAction)

masternode vote action



BumpIdentityNonceAction(BumpIdentityNonceAction)

bump identity nonce action this can only come in this form from identity state transitions that do not use asset locks it will also only happen if the state validation fails



BumpIdentityDataContractNonceAction(BumpIdentityDataContractNonceAction)

bump identity contract nonce action this can only come in this form from the document contract update state transition it will also only happen if the state validation fails



PartiallyUseAssetLockAction(PartiallyUseAssetLockAction)

partially use the asset lock for funding invalid asset lock transactions like identity top up and identity create



BumpAddressInputNoncesAction(BumpAddressInputNoncesAction)

partially use the asset lock for funding invalid asset lock transactions like identity top up and identity create



ShieldAction(ShieldTransitionAction)

shield (address -> shielded pool)



ShieldedTransferAction(ShieldedTransferTransitionAction)

shielded transfer (shielded -> shielded)



UnshieldAction(UnshieldTransitionAction)

unshield (shielded pool -> address)



ShieldFromAssetLockAction(ShieldFromAssetLockTransitionAction)

shield from asset lock (L1 asset lock -> shielded pool)



ShieldedWithdrawalAction(ShieldedWithdrawalTransitionAction)

shielded withdrawal (shielded pool -> L1 core address)

Implementations

Source

impl StateTransitionAction

pub fn user_fee_increase(&self) -> UserFeeIncrease

The fee multiplier for the action