pub enum IdentityCreateTransitionAction {
V0(IdentityCreateTransitionActionV0),
}Expand description
action
Variants
Implementations
Sourceimpl IdentityCreateTransitionAction
impl IdentityCreateTransitionAction
Sourcepub fn try_from(
value: IdentityCreateTransition,
signable_bytes_hasher: SignableBytesHasher,
asset_lock_value_to_be_consumed: AssetLockValue,
) -> Result<Self, ConsensusError>
pub fn try_from( value: IdentityCreateTransition, signable_bytes_hasher: SignableBytesHasher, asset_lock_value_to_be_consumed: AssetLockValue, ) -> Result<Self, ConsensusError>
try from
Sourcepub fn try_from_borrowed(
value: &IdentityCreateTransition,
signable_bytes_hasher: SignableBytesHasher,
asset_lock_value_to_be_consumed: AssetLockValue,
) -> Result<Self, ConsensusError>
pub fn try_from_borrowed( value: &IdentityCreateTransition, signable_bytes_hasher: SignableBytesHasher, asset_lock_value_to_be_consumed: AssetLockValue, ) -> Result<Self, ConsensusError>
try from borrowed
Sourceimpl IdentityCreateTransitionAction
action
impl IdentityCreateTransitionAction
action
Sourcepub fn public_keys(&self) -> &Vec<IdentityPublicKey>
pub fn public_keys(&self) -> &Vec<IdentityPublicKey>
Public Keys
Sourcepub fn asset_lock_value_to_be_consumed(&self) -> &AssetLockValue
pub fn asset_lock_value_to_be_consumed(&self) -> &AssetLockValue
Asset lock value to be consumed The initial balance is equal to the remaining credit value in the asset lock value
Sourcepub fn asset_lock_value_to_be_consumed_owned(self) -> AssetLockValue
pub fn asset_lock_value_to_be_consumed_owned(self) -> AssetLockValue
Asset lock value to be consumed The initial balance is equal to the remaining credit value in the asset lock value
Sourcepub fn identity_id(&self) -> Identifier
pub fn identity_id(&self) -> Identifier
Identity Id
Sourcepub fn asset_lock_outpoint(&self) -> Bytes36
pub fn asset_lock_outpoint(&self) -> Bytes36
Asset Lock Outpoint
Sourcepub fn user_fee_increase(&self) -> UserFeeIncrease
pub fn user_fee_increase(&self) -> UserFeeIncrease
fee multiplier