pub struct BumpIdentityNonceActionV0 {
pub identity_id: Identifier,
pub identity_nonce: IdentityNonce,
pub user_fee_increase: UserFeeIncrease,
}Expand description
Version 0 of the bump identity nonce action This action is performed when we want to pay for validation of the state transition but not execute it
Fields
identity_id: IdentifierThe identity id
identity_nonce: IdentityNonceThe identity contract nonce, this is used to stop replay attacks
user_fee_increase: UserFeeIncreasefee multiplier
Implementations
Sourceimpl BumpIdentityNonceActionV0
impl BumpIdentityNonceActionV0
Sourcepub fn from_identity_update(value: IdentityUpdateTransitionV0) -> Self
pub fn from_identity_update(value: IdentityUpdateTransitionV0) -> Self
from identity update
Sourcepub fn from_borrowed_identity_update(value: &IdentityUpdateTransitionV0) -> Self
pub fn from_borrowed_identity_update(value: &IdentityUpdateTransitionV0) -> Self
from borrowed identity update
Sourcepub fn from_identity_update_action(
value: IdentityUpdateTransitionActionV0,
) -> Self
pub fn from_identity_update_action( value: IdentityUpdateTransitionActionV0, ) -> Self
from identity update action
Sourcepub fn from_borrowed_identity_update_action(
value: &IdentityUpdateTransitionActionV0,
) -> Self
pub fn from_borrowed_identity_update_action( value: &IdentityUpdateTransitionActionV0, ) -> Self
from borrowed identity update action
Sourcepub fn from_contract_create(value: DataContractCreateTransitionV0) -> Self
pub fn from_contract_create(value: DataContractCreateTransitionV0) -> Self
from contract create
Sourcepub fn from_borrowed_contract_create(
value: &DataContractCreateTransitionV0,
) -> Self
pub fn from_borrowed_contract_create( value: &DataContractCreateTransitionV0, ) -> Self
from borrowed contract create
Sourcepub fn from_contract_create_action(
value: DataContractCreateTransitionActionV0,
) -> Self
pub fn from_contract_create_action( value: DataContractCreateTransitionActionV0, ) -> Self
from contract create action
Sourcepub fn from_borrowed_contract_create_action(
value: &DataContractCreateTransitionActionV0,
) -> Self
pub fn from_borrowed_contract_create_action( value: &DataContractCreateTransitionActionV0, ) -> Self
from contract create action
Sourcepub fn from_identity_credit_transfer(
value: IdentityCreditTransferTransitionV0,
) -> Self
pub fn from_identity_credit_transfer( value: IdentityCreditTransferTransitionV0, ) -> Self
from identity credit transfer
Sourcepub fn from_borrowed_identity_credit_transfer(
value: &IdentityCreditTransferTransitionV0,
) -> Self
pub fn from_borrowed_identity_credit_transfer( value: &IdentityCreditTransferTransitionV0, ) -> Self
from borrowed identity credit transfer
Sourcepub fn from_identity_credit_transfer_action(
value: IdentityCreditTransferTransitionActionV0,
) -> Self
pub fn from_identity_credit_transfer_action( value: IdentityCreditTransferTransitionActionV0, ) -> Self
from identity credit transfer action
Sourcepub fn from_borrowed_identity_credit_transfer_action(
value: &IdentityCreditTransferTransitionActionV0,
) -> Self
pub fn from_borrowed_identity_credit_transfer_action( value: &IdentityCreditTransferTransitionActionV0, ) -> Self
from borrowed identity credit transfer action
Sourcepub fn from_identity_credit_withdrawal(
value: IdentityCreditWithdrawalTransition,
) -> Self
pub fn from_identity_credit_withdrawal( value: IdentityCreditWithdrawalTransition, ) -> Self
from identity credit withdrawal
Sourcepub fn from_borrowed_identity_credit_withdrawal(
value: &IdentityCreditWithdrawalTransition,
) -> Self
pub fn from_borrowed_identity_credit_withdrawal( value: &IdentityCreditWithdrawalTransition, ) -> Self
from borrowed identity credit withdrawal
Sourcepub fn from_identity_credit_withdrawal_action(
value: IdentityCreditWithdrawalTransitionActionV0,
) -> Self
pub fn from_identity_credit_withdrawal_action( value: IdentityCreditWithdrawalTransitionActionV0, ) -> Self
from identity credit withdrawal action
Sourcepub fn from_borrowed_identity_credit_withdrawal_action(
value: &IdentityCreditWithdrawalTransitionActionV0,
) -> Self
pub fn from_borrowed_identity_credit_withdrawal_action( value: &IdentityCreditWithdrawalTransitionActionV0, ) -> Self
from borrowed identity credit withdrawal action