decode_u64

Function decode_u64 

pub fn decode_u64(bytes: &[u8]) -> Result<u64, Error>
Decodes a 64-bit unsigned integer from a vector of bytes encoded with encode_u64.

Arguments

  • bytes - A vector of bytes representing the encoded 64-bit unsigned integer.

Returns

  • A 64-bit unsigned integer decoded from the input bytes.

Panics

This function will panic if the input vector does not have exactly 8 bytes.