vote_poll_end_dates

Function vote_poll_end_dates 

pub fn vote_poll_end_dates(
    drive: &Drive,
    platform_version: &PlatformVersion,
) -> BTreeMap<TimestampMillis, BTreeSet<Identifier>>
Every end date of the vote poll end-date queries, with the unique ids of the vote polls listed under it; an end date that lists none shows as an empty set.