setup_drive

Function setup_drive 

pub fn setup_drive(drive_config: Option<DriveConfig>) -> Drive
Sets up Drive using a temporary directory and the optionally given Drive configuration settings.

The returned Drive owns the directory, which is removed when the Drive is dropped.