pub struct DriveConfig {
pub batching_consistency_verification: bool,
pub has_raw_enabled: bool,
pub grovedb_verify_on_startup: bool,
pub default_query_limit: u16,
pub epochs_per_era: u16,
pub max_query_limit: u16,
pub default_genesis_time: Option<u64>,
pub data_contracts_global_cache_size: u64,
pub data_contracts_block_cache_size: u64,
pub network: Network,
}Expand description
Drive configuration struct
Fields
batching_consistency_verification: boolBoolean if batching consistency verification is enabled
has_raw_enabled: boolBoolean if has_raw is enabled
grovedb_verify_on_startup: boolBoolean if GroveDB verification should happen on startup
default_query_limit: u16The default returned count if no limit is set
epochs_per_era: u16The default returned count if no limit is set
max_query_limit: u16The limit for user defined queries
default_genesis_time: Option<u64>Default genesis time
data_contracts_global_cache_size: u64Maximum number of contracts in global cache
data_contracts_block_cache_size: u64Maximum number of contracts in block candidate cache
network: NetworkThe network type
Implementations
Sourceimpl DriveConfig
impl DriveConfig
Sourcepub fn default_network() -> Network
pub fn default_network() -> Network
The default network type for mainnet
Sourcepub fn default_testnet() -> Self
pub fn default_testnet() -> Self
The default testnet configuration