LowLevelDriveOperation

Enum LowLevelDriveOperation 

pub enum LowLevelDriveOperation {
    GroveOperation(QualifiedGroveDbOp),
    FunctionOperation(FunctionOp),
    CalculatedCostOperation(OperationCost),
    PreCalculatedFeeResult(FeeResult),
}
Drive operation

Variants



GroveOperation(QualifiedGroveDbOp)

Grove operation



FunctionOperation(FunctionOp)

A drive operation



CalculatedCostOperation(OperationCost)

Calculated cost operation



PreCalculatedFeeResult(FeeResult)

Pre Calculated Fee Result

Implementations

Source

impl LowLevelDriveOperation

pub fn consume_to_fees_v0( drive_operations: Vec<LowLevelDriveOperation>, epoch: &Epoch, epochs_per_era: u16, fee_version: &FeeVersion, previous_fee_versions: Option<&CachedEpochIndexFeeVersions>, ) -> Result<Vec<FeeResult>, Error>

Returns a list of the costs of the Drive operations. Should only be used by Calculate fee

pub fn operation_cost(self) -> Result<OperationCost, Error>

Returns the cost of this operation

pub fn combine_cost_operations( operations: &[LowLevelDriveOperation], ) -> OperationCost

Filters the groveDB ops from a list of operations and puts them in a GroveDbOpBatch.

pub fn grovedb_operations_batch( insert_operations: &[LowLevelDriveOperation], ) -> GroveDbOpBatch

Filters the groveDB ops from a list of operations and puts them in a GroveDbOpBatch.

pub fn grovedb_operations_batch_consume( insert_operations: Vec<LowLevelDriveOperation>, ) -> GroveDbOpBatch

Filters the groveDB ops from a list of operations and puts them in a GroveDbOpBatch.

pub fn grovedb_operations_batch_consume_with_leftovers( insert_operations: Vec<LowLevelDriveOperation>, ) -> (GroveDbOpBatch, Vec<LowLevelDriveOperation>)

Filters the groveDB ops from a list of operations and puts them in a GroveDbOpBatch.

pub fn grovedb_operations_consume( insert_operations: Vec<LowLevelDriveOperation>, ) -> Vec<QualifiedGroveDbOp>

Filters the groveDB ops from a list of operations and collects them in a Vec<QualifiedGroveDbOp>.

pub fn for_known_path_key_empty_tree( path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty tree at the given path and key

pub fn for_known_path_key_empty_sum_tree( path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty sum tree at the given path and key

pub fn for_known_path_key_empty_big_sum_tree( path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty sum tree at the given path and key

pub fn for_known_path_key_empty_count_tree( path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty count tree at the given path and key

pub fn for_known_path_key_empty_count_sum_tree( path: Vec<Vec<u8>>, key: Vec<u8>, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty count tree at the given path and key

pub fn for_estimated_path_key_empty_tree( path: KeyInfoPath, key: KeyInfo, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty tree at the given path and key

pub fn for_estimated_path_key_empty_sum_tree( path: KeyInfoPath, key: KeyInfo, storage_flags: Option<&StorageFlags>, ) -> Self

Sets GroveOperation for inserting an empty sum tree at the given path and key

pub fn insert_for_known_path_key_element( path: Vec<Vec<u8>>, key: Vec<u8>, element: Element, ) -> Self

Sets GroveOperation for inserting an element at the given path and key

pub fn replace_for_known_path_key_element( path: Vec<Vec<u8>>, key: Vec<u8>, element: Element, ) -> Self

Sets GroveOperation for replacement of an element at the given path and key

pub fn patch_for_known_path_key_element( path: Vec<Vec<u8>>, key: Vec<u8>, element: Element, change_in_bytes: i32, ) -> Self

Sets GroveOperation for patching of an element at the given path and key This is different from replacement which does not add or delete bytes

pub fn insert_for_estimated_path_key_element( path: KeyInfoPath, key: KeyInfo, element: Element, ) -> Self

Sets GroveOperation for inserting an element at an unknown estimated path and key

pub fn replace_for_estimated_path_key_element( path: KeyInfoPath, key: KeyInfo, element: Element, ) -> Self

Sets GroveOperation for replacement of an element at an unknown estimated path and key

pub fn refresh_reference_for_known_path_key_reference_info( path: Vec<Vec<u8>>, key: Vec<u8>, reference_path_type: ReferencePathType, max_reference_hop: MaxReferenceHop, flags: Option<ElementFlags>, trust_refresh_reference: bool, ) -> Self

Sets GroveOperation for refresh of a reference at the given path and key