Enum Element
pub enum Element {
Show 15 variants
Item(Vec<u8>, Option<Vec<u8>>),
Reference(ReferencePathType, Option<u8>, Option<Vec<u8>>),
Tree(Option<Vec<u8>>, Option<Vec<u8>>),
SumItem(i64, Option<Vec<u8>>),
SumTree(Option<Vec<u8>>, i64, Option<Vec<u8>>),
BigSumTree(Option<Vec<u8>>, i128, Option<Vec<u8>>),
CountTree(Option<Vec<u8>>, u64, Option<Vec<u8>>),
CountSumTree(Option<Vec<u8>>, u64, i64, Option<Vec<u8>>),
ProvableCountTree(Option<Vec<u8>>, u64, Option<Vec<u8>>),
ItemWithSumItem(Vec<u8>, i64, Option<Vec<u8>>),
ProvableCountSumTree(Option<Vec<u8>>, u64, i64, Option<Vec<u8>>),
CommitmentTree(u64, u8, Option<Vec<u8>>),
MmrTree(u64, Option<Vec<u8>>),
BulkAppendTree(u64, u8, Option<Vec<u8>>),
DenseAppendOnlyFixedSizeTree(u16, u8, Option<Vec<u8>>),
}Expand description
Variants of GroveDB stored entities
ONLY APPEND TO THIS LIST!!! Because of how serialization works.
Variants
Item(Vec<u8>, Option<Vec<u8>>)
An ordinary value
Reference(ReferencePathType, Option<u8>, Option<Vec<u8>>)
A reference to an object by its path
Tree(Option<Vec<u8>>, Option<Vec<u8>>)
A subtree, contains the prefixed key representing the root of the subtree.
SumItem(i64, Option<Vec<u8>>)
Signed integer value that can be totaled in a sum tree
SumTree(Option<Vec<u8>>, i64, Option<Vec<u8>>)
Same as Element::Tree but underlying Merk sums value of it’s summable nodes
BigSumTree(Option<Vec<u8>>, i128, Option<Vec<u8>>)
Same as Element::Tree but underlying Merk sums value of it’s summable nodes in big form i128 The big sum tree is valuable if you have a big sum tree of sum trees
CountTree(Option<Vec<u8>>, u64, Option<Vec<u8>>)
Same as Element::Tree but underlying Merk counts value of its countable nodes
CountSumTree(Option<Vec<u8>>, u64, i64, Option<Vec<u8>>)
Combines Element::SumTree and Element::CountTree
ProvableCountTree(Option<Vec<u8>>, u64, Option<Vec<u8>>)
Same as Element::CountTree but includes counts in cryptographic state
ItemWithSumItem(Vec<u8>, i64, Option<Vec<u8>>)
An ordinary value with a sum value
ProvableCountSumTree(Option<Vec<u8>>, u64, i64, Option<Vec<u8>>)
Same as Element::CountSumTree but includes counts in cryptographic state (sum is tracked but NOT included in hash, only count is)
CommitmentTree(u64, u8, Option<Vec<u8>>)
Orchard-style commitment tree: combines a BulkAppendTree (for efficient append-only storage of cmx||encrypted_note payloads with epoch compaction) and a Sinsemilla Frontier (for anchor computation). Items are stored in the data namespace via BulkAppendTree; the frontier is stored in data storage.
Fields: (total_count, chunk_power, flags)
total_count: Number of notes appended so far.chunk_power: Log2 of the chunk size (actual size =1 << chunk_power).flags: Optional per-element metadata.
The Sinsemilla frontier root hash is not stored in the Element; it is persisted in data storage and verified by opening the frontier. The BulkAppendTree state_root flows as the Merk child hash.
MmrTree(u64, Option<Vec<u8>>)
MMR (Merkle Mountain Range) tree: append-only authenticated data structure with zero rotations, O(N) total hashes, sequential I/O.
The MMR root hash is stored as the Merk child hash (not in the Element).
Fields: (mmr_size, flags)
mmr_size: Total number of MMR nodes (internal + leaves).flags: Optional per-element metadata.
BulkAppendTree(u64, u8, Option<Vec<u8>>)
Bulk-append tree: two-level structure with a dense Merkle buffer that compacts into chunk blobs stored in an MMR.
Fields: (total_count, chunk_power, flags)
total_count: Number of items appended so far.chunk_power: Log2 of the chunk size (actual size =1 << chunk_power).flags: Optional per-element metadata.
The state root (blake3(mmr_root || buffer_hash)) flows through the
Merk child hash mechanism (insert_subtree’s subtree_root_hash
parameter).
DenseAppendOnlyFixedSizeTree(u16, u8, Option<Vec<u8>>)
Dense fixed-sized Merkle tree: a complete binary tree of height h with 2^h - 1 positions. Nodes are filled sequentially in level-order (BFS). Root hash flows through the Merk child hash mechanism (insert_subtree’s subtree_root_hash parameter).
Fields: (count, height, flags)
count: Number of values inserted so far.height: Tree height h; the tree has 2^h - 1 positions.flags: Optional per-element metadata.
Implementations
impl Element
impl Element
pub fn empty_tree() -> Element
pub fn empty_tree() -> Element
Set element to default empty tree without flags
pub fn empty_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty tree with flags
pub fn empty_sum_tree() -> Element
pub fn empty_sum_tree() -> Element
Set element to default empty sum tree without flags
pub fn empty_big_sum_tree() -> Element
pub fn empty_big_sum_tree() -> Element
Set element to default empty big sum tree without flags
pub fn empty_count_tree() -> Element
pub fn empty_count_tree() -> Element
Set element to default empty count tree without flags
pub fn empty_count_sum_tree() -> Element
pub fn empty_count_sum_tree() -> Element
Set element to default empty count sum tree without flags
pub fn empty_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty sum tree with flags
pub fn empty_big_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_big_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty sum tree with flags
pub fn empty_count_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_count_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty count tree with flags
pub fn empty_count_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_count_sum_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty count sum tree with flags
pub fn new_item_with_flags(
item_value: Vec<u8>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_item_with_flags( item_value: Vec<u8>, flags: Option<Vec<u8>>, ) -> Element
Set element to an item with flags
pub fn new_sum_item(value: i64) -> Element
pub fn new_sum_item(value: i64) -> Element
Set element to a sum item without flags
pub fn new_sum_item_with_flags(value: i64, flags: Option<Vec<u8>>) -> Element
pub fn new_sum_item_with_flags(value: i64, flags: Option<Vec<u8>>) -> Element
Set element to a sum item with flags
pub fn new_item_with_sum_item(item_value: Vec<u8>, sum_value: i64) -> Element
pub fn new_item_with_sum_item(item_value: Vec<u8>, sum_value: i64) -> Element
Set element to an item with sum value (no flags)
pub fn new_item_with_sum_item_with_flags(
item_value: Vec<u8>,
sum_value: i64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_item_with_sum_item_with_flags( item_value: Vec<u8>, sum_value: i64, flags: Option<Vec<u8>>, ) -> Element
Set element to an item with sum value and flags
pub fn new_reference(reference_path: ReferencePathType) -> Element
pub fn new_reference(reference_path: ReferencePathType) -> Element
Set element to a reference without flags
pub fn new_reference_with_flags(
reference_path: ReferencePathType,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_reference_with_flags( reference_path: ReferencePathType, flags: Option<Vec<u8>>, ) -> Element
Set element to a reference with flags
pub fn new_reference_with_hops(
reference_path: ReferencePathType,
max_reference_hop: Option<u8>,
) -> Element
pub fn new_reference_with_hops( reference_path: ReferencePathType, max_reference_hop: Option<u8>, ) -> Element
Set element to a reference with hops, no flags
pub fn new_reference_with_max_hops_and_flags(
reference_path: ReferencePathType,
max_reference_hop: Option<u8>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_reference_with_max_hops_and_flags( reference_path: ReferencePathType, max_reference_hop: Option<u8>, flags: Option<Vec<u8>>, ) -> Element
Set element to a reference with max hops and flags
pub fn new_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a tree with flags
pub fn new_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a sum tree without flags
pub fn new_sum_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_sum_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a sum tree with flags
pub fn new_sum_tree_with_flags_and_sum_value(
maybe_root_key: Option<Vec<u8>>,
sum_value: i64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_sum_tree_with_flags_and_sum_value( maybe_root_key: Option<Vec<u8>>, sum_value: i64, flags: Option<Vec<u8>>, ) -> Element
Set element to a sum tree with flags and sum value
pub fn new_big_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_big_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a big sum tree without flags
pub fn new_big_sum_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_big_sum_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a big sum tree with flags
pub fn new_big_sum_tree_with_flags_and_sum_value(
maybe_root_key: Option<Vec<u8>>,
big_sum_value: i128,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_big_sum_tree_with_flags_and_sum_value( maybe_root_key: Option<Vec<u8>>, big_sum_value: i128, flags: Option<Vec<u8>>, ) -> Element
Set element to a big sum tree with flags and sum value
pub fn new_count_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_count_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a count tree without flags
pub fn new_count_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_count_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a count tree with flags
pub fn new_count_tree_with_flags_and_count_value(
maybe_root_key: Option<Vec<u8>>,
count_value: u64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_count_tree_with_flags_and_count_value( maybe_root_key: Option<Vec<u8>>, count_value: u64, flags: Option<Vec<u8>>, ) -> Element
Set element to a count tree with flags and sum value
pub fn new_count_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_count_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a count sum tree without flags
pub fn new_count_sum_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_count_sum_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a count sum tree with flags
pub fn new_count_sum_tree_with_flags_and_sum_and_count_value(
maybe_root_key: Option<Vec<u8>>,
count_value: u64,
sum_value: i64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_count_sum_tree_with_flags_and_sum_and_count_value( maybe_root_key: Option<Vec<u8>>, count_value: u64, sum_value: i64, flags: Option<Vec<u8>>, ) -> Element
Set element to a count sum tree with flags and sum value
pub fn empty_provable_count_tree() -> Element
pub fn empty_provable_count_tree() -> Element
Set element to default empty provable count tree without flags
pub fn empty_provable_count_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_provable_count_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to default empty provable count tree with flags
pub fn new_provable_count_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_provable_count_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a provable count tree without flags
pub fn new_provable_count_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_provable_count_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a provable count tree with flags
pub fn new_provable_count_tree_with_flags_and_count_value(
maybe_root_key: Option<Vec<u8>>,
count_value: u64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_provable_count_tree_with_flags_and_count_value( maybe_root_key: Option<Vec<u8>>, count_value: u64, flags: Option<Vec<u8>>, ) -> Element
Set element to a provable count tree with flags and count value
pub fn empty_provable_count_sum_tree() -> Element
pub fn empty_provable_count_sum_tree() -> Element
Set element to default empty provable count sum tree without flags
pub fn empty_provable_count_sum_tree_with_flags(
flags: Option<Vec<u8>>,
) -> Element
pub fn empty_provable_count_sum_tree_with_flags( flags: Option<Vec<u8>>, ) -> Element
Set element to default empty provable count sum tree with flags
pub fn new_provable_count_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
pub fn new_provable_count_sum_tree(maybe_root_key: Option<Vec<u8>>) -> Element
Set element to a provable count sum tree without flags
pub fn new_provable_count_sum_tree_with_flags(
maybe_root_key: Option<Vec<u8>>,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_provable_count_sum_tree_with_flags( maybe_root_key: Option<Vec<u8>>, flags: Option<Vec<u8>>, ) -> Element
Set element to a provable count sum tree with flags
pub fn new_provable_count_sum_tree_with_flags_and_sum_and_count_value(
maybe_root_key: Option<Vec<u8>>,
count_value: u64,
sum_value: i64,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_provable_count_sum_tree_with_flags_and_sum_and_count_value( maybe_root_key: Option<Vec<u8>>, count_value: u64, sum_value: i64, flags: Option<Vec<u8>>, ) -> Element
Set element to a provable count sum tree with flags, count, and sum value
pub fn empty_commitment_tree(chunk_power: u8) -> Result<Element, ElementError>
pub fn empty_commitment_tree(chunk_power: u8) -> Result<Element, ElementError>
Set element to an empty commitment tree.
Returns InvalidInput if chunk_power > 31.
pub fn empty_commitment_tree_with_flags(
chunk_power: u8,
flags: Option<Vec<u8>>,
) -> Result<Element, ElementError>
pub fn empty_commitment_tree_with_flags( chunk_power: u8, flags: Option<Vec<u8>>, ) -> Result<Element, ElementError>
Set element to an empty commitment tree with flags.
Returns InvalidInput if chunk_power > 31.
pub fn new_commitment_tree(
total_count: u64,
chunk_power: u8,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_commitment_tree( total_count: u64, chunk_power: u8, flags: Option<Vec<u8>>, ) -> Element
Set element to a commitment tree with all fields
pub fn empty_mmr_tree() -> Element
pub fn empty_mmr_tree() -> Element
Set element to an empty MMR tree
pub fn empty_mmr_tree_with_flags(flags: Option<Vec<u8>>) -> Element
pub fn empty_mmr_tree_with_flags(flags: Option<Vec<u8>>) -> Element
Set element to an empty MMR tree with flags
pub fn new_mmr_tree(mmr_size: u64, flags: Option<Vec<u8>>) -> Element
pub fn new_mmr_tree(mmr_size: u64, flags: Option<Vec<u8>>) -> Element
Set element to an MMR tree with the given size
pub fn empty_bulk_append_tree(chunk_power: u8) -> Result<Element, ElementError>
pub fn empty_bulk_append_tree(chunk_power: u8) -> Result<Element, ElementError>
Set element to an empty bulk append tree without flags.
Returns InvalidInput if chunk_power > 31.
pub fn empty_bulk_append_tree_with_flags(
chunk_power: u8,
flags: Option<Vec<u8>>,
) -> Result<Element, ElementError>
pub fn empty_bulk_append_tree_with_flags( chunk_power: u8, flags: Option<Vec<u8>>, ) -> Result<Element, ElementError>
Set element to an empty bulk append tree with flags.
Returns InvalidInput if chunk_power > 31.
pub fn new_bulk_append_tree(
total_count: u64,
chunk_power: u8,
flags: Option<Vec<u8>>,
) -> Element
pub fn new_bulk_append_tree( total_count: u64, chunk_power: u8, flags: Option<Vec<u8>>, ) -> Element
Set element to a bulk append tree with all fields
pub fn empty_dense_tree(height: u8) -> Element
pub fn empty_dense_tree(height: u8) -> Element
Set element to an empty dense tree without flags
impl Element
impl Element
pub fn sum_value_or_default(&self) -> i64
pub fn sum_value_or_default(&self) -> i64
Decoded the integer value in the SumItem element type, returns 0 for everything else
pub fn count_value_or_default(&self) -> u64
pub fn count_value_or_default(&self) -> u64
Decoded the integer value in the CountTree element type, returns 1 for everything else
pub fn count_sum_value_or_default(&self) -> (u64, i64)
pub fn count_sum_value_or_default(&self) -> (u64, i64)
Decoded the count and sum values from the element type, returns (1, 0) for elements without count/sum semantics
pub fn big_sum_value_or_default(&self) -> i128
pub fn big_sum_value_or_default(&self) -> i128
Decoded the integer value in the SumItem element type, returns 0 for everything else
pub fn as_sum_item_value(&self) -> Result<i64, ElementError>
pub fn as_sum_item_value(&self) -> Result<i64, ElementError>
Decoded the integer value in the SumItem element type
pub fn into_sum_item_value(self) -> Result<i64, ElementError>
pub fn into_sum_item_value(self) -> Result<i64, ElementError>
Decoded the integer value in the SumItem element type
pub fn as_sum_tree_value(&self) -> Result<i64, ElementError>
pub fn as_sum_tree_value(&self) -> Result<i64, ElementError>
Decoded the integer value in the SumTree element type
pub fn into_sum_tree_value(self) -> Result<i64, ElementError>
pub fn into_sum_tree_value(self) -> Result<i64, ElementError>
Decoded the integer value in the SumTree element type
pub fn as_item_bytes(&self) -> Result<&[u8], ElementError>
pub fn as_item_bytes(&self) -> Result<&[u8], ElementError>
Gives the item value in the Item element type
pub fn into_item_bytes(self) -> Result<Vec<u8>, ElementError>
pub fn into_item_bytes(self) -> Result<Vec<u8>, ElementError>
Gives the item value in the Item element type
pub fn into_reference_path_type(self) -> Result<ReferencePathType, ElementError>
pub fn into_reference_path_type(self) -> Result<ReferencePathType, ElementError>
Gives the reference path type in the Reference element type
pub fn is_sum_tree(&self) -> bool
pub fn is_sum_tree(&self) -> bool
Check if the element is a sum tree
pub fn is_big_sum_tree(&self) -> bool
pub fn is_big_sum_tree(&self) -> bool
Check if the element is a big sum tree
pub fn is_basic_tree(&self) -> bool
pub fn is_basic_tree(&self) -> bool
Check if the element is a tree but not a sum tree
pub fn is_any_tree(&self) -> bool
pub fn is_any_tree(&self) -> bool
Check if the element is a tree
pub fn is_commitment_tree(&self) -> bool
pub fn is_commitment_tree(&self) -> bool
Check if the element is a commitment tree
pub fn is_mmr_tree(&self) -> bool
pub fn is_mmr_tree(&self) -> bool
Check if the element is an MMR tree
pub fn is_bulk_append_tree(&self) -> bool
pub fn is_bulk_append_tree(&self) -> bool
Check if the element is a bulk append tree
pub fn is_dense_tree(&self) -> bool
pub fn is_dense_tree(&self) -> bool
Check if the element is a dense append-only fixed-size tree
pub fn uses_non_merk_data_storage(&self) -> bool
pub fn uses_non_merk_data_storage(&self) -> bool
Check if the element is a tree type that stores data in the data namespace as non-Merk entries. These tree types have an always-empty Merk (root_key = None) and never contain child subtrees. The data namespace must be cleared directly rather than iterated as Merk elements.
Note: This must be kept in sync with
TreeType::uses_non_merk_data_storage() in the merk crate.
pub fn non_merk_entry_count(&self) -> Option<u64>
pub fn non_merk_entry_count(&self) -> Option<u64>
Returns the entry count for non-Merk data tree types, or None for
regular Merk trees and non-tree elements. This is used by delete
and is_empty_tree operations to determine emptiness without
iterating the data namespace.
pub fn is_non_empty_tree(&self) -> bool
pub fn is_non_empty_tree(&self) -> bool
Check if the element is a non-empty tree that should have child data.
For merk-backed trees this means the root key is Some(_) (at least one
node). Non-merk tree types (MmrTree, BulkAppendTree, CommitmentTree,
DenseAppendOnlyFixedSizeTree) always carry their own data and are
considered non-empty regardless of their count field.
pub fn is_non_empty_merk_tree(&self) -> bool
pub fn is_non_empty_merk_tree(&self) -> bool
Check if the element is a non-empty Merk-backed tree.
Returns true only for standard Merk trees (Tree, SumTree, BigSumTree,
CountTree, CountSumTree, ProvableCountTree, ProvableCountSumTree)
with a Some(_) root key. Excludes non-Merk tree types (MmrTree,
BulkAppendTree, CommitmentTree, DenseAppendOnlyFixedSizeTree).
pub fn is_reference(&self) -> bool
pub fn is_reference(&self) -> bool
Check if the element is a reference
pub fn is_any_item(&self) -> bool
pub fn is_any_item(&self) -> bool
Check if the element is an item
pub fn is_basic_item(&self) -> bool
pub fn is_basic_item(&self) -> bool
Check if the element is an item
pub fn has_basic_item(&self) -> bool
pub fn has_basic_item(&self) -> bool
Check if the element is an item
pub fn is_sum_item(&self) -> bool
pub fn is_sum_item(&self) -> bool
Check if the element is a sum item
pub fn is_item_with_sum_item(&self) -> bool
pub fn is_item_with_sum_item(&self) -> bool
Check if the element is a sum item
pub fn get_flags_owned(self) -> Option<Vec<u8>>
pub fn get_flags_owned(self) -> Option<Vec<u8>>
Grab the optional flag stored in an element
pub fn get_flags_mut(&mut self) -> &mut Option<Vec<u8>>
pub fn get_flags_mut(&mut self) -> &mut Option<Vec<u8>>
Grab the optional flag stored in an element as mutable
pub fn required_item_space(
len: u32,
flag_len: u32,
grove_version: &GroveVersion,
) -> Result<u32, ElementError>
pub fn required_item_space( len: u32, flag_len: u32, grove_version: &GroveVersion, ) -> Result<u32, ElementError>
Get the required item space
impl Element
impl Element
pub fn serialize(
&self,
grove_version: &GroveVersion,
) -> Result<Vec<u8>, ElementError>
pub fn serialize( &self, grove_version: &GroveVersion, ) -> Result<Vec<u8>, ElementError>
Serializes self. Returns vector of u8s.
pub fn serialized_size(
&self,
grove_version: &GroveVersion,
) -> Result<usize, ElementError>
pub fn serialized_size( &self, grove_version: &GroveVersion, ) -> Result<usize, ElementError>
Serializes self. Returns usize.
pub fn deserialize(
bytes: &[u8],
grove_version: &GroveVersion,
) -> Result<Element, ElementError>
pub fn deserialize( bytes: &[u8], grove_version: &GroveVersion, ) -> Result<Element, ElementError>
Deserializes given bytes and sets as self
impl Element
impl Element
pub fn element_type(&self) -> ElementType
pub fn element_type(&self) -> ElementType
Returns the ElementType for this element.
pub fn type_str(&self) -> &str