pub fn contract_lookup_fn_for_contract<'a>(
data_contract: Arc<DataContract>,
) -> Box<ContractLookupFn<'a>>Expand description
Creates a ContractLookupFn function that returns provided data contract when requested.
Arguments
data_contract- Arcto return
Returns
ContractLookupFn that will return the data_contract, or None if
the requested contract is not the same as the provided one.