pub struct DriveDocumentQuery<'a> {
pub contract: &'a DataContract,
pub document_type: DocumentTypeRef<'a>,
pub internal_clauses: InternalClauses,
pub offset: Option<u16>,
pub limit: Option<u16>,
pub order_by: IndexMap<String, OrderClause>,
pub start_at: Option<[u8; 32]>,
pub start_at_included: bool,
pub block_time_ms: Option<u64>,
}Expand description
Drive query struct
Fields
contract: &'a DataContractDataContract
document_type: DocumentTypeRef<'a>Document type
internal_clauses: InternalClausesInternal clauses
offset: Option<u16>Offset
limit: Option<u16>Limit
order_by: IndexMap<String, OrderClause>Order by
start_at: Option<[u8; 32]>Start at document id
start_at_included: boolStart at included
block_time_ms: Option<u64>Block time
Implementations
Sourceimpl<'a> DriveDocumentQuery<'a>
impl<'a> DriveDocumentQuery<'a>
Sourcepub fn new_primary_key_single_item_query(
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
id: Identifier,
) -> Self
pub fn new_primary_key_single_item_query( contract: &'a DataContract, document_type: DocumentTypeRef<'a>, id: Identifier, ) -> Self
Gets a document by their primary key
Sourcepub fn any_item_query(
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
) -> Self
pub fn any_item_query( contract: &'a DataContract, document_type: DocumentTypeRef<'a>, ) -> Self
Returns any item
Sourcepub fn all_items_query(
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
limit: Option<u16>,
) -> Self
pub fn all_items_query( contract: &'a DataContract, document_type: DocumentTypeRef<'a>, limit: Option<u16>, ) -> Self
Returns all items
Sourcepub fn is_for_primary_key(&self) -> bool
pub fn is_for_primary_key(&self) -> bool
Returns true if the query clause if for primary keys.
Sourcepub fn from_cbor(
query_cbor: &[u8],
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
config: &DriveConfig,
) -> Result<Self, Error>
pub fn from_cbor( query_cbor: &[u8], contract: &'a DataContract, document_type: DocumentTypeRef<'a>, config: &DriveConfig, ) -> Result<Self, Error>
Converts a query CBOR to a DriveQuery.
Sourcepub fn from_value(
query_value: Value,
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
config: &DriveConfig,
) -> Result<Self, Error>
pub fn from_value( query_value: Value, contract: &'a DataContract, document_type: DocumentTypeRef<'a>, config: &DriveConfig, ) -> Result<Self, Error>
Converts a query Value to a DriveQuery.
Sourcepub fn from_btree_map_value(
query_document: BTreeMap<String, Value>,
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
config: &DriveConfig,
) -> Result<Self, Error>
pub fn from_btree_map_value( query_document: BTreeMap<String, Value>, contract: &'a DataContract, document_type: DocumentTypeRef<'a>, config: &DriveConfig, ) -> Result<Self, Error>
Converts a query Value to a DriveQuery.
Sourcepub fn from_decomposed_values(
where_clause: Value,
order_by: Option<Value>,
maybe_limit: Option<u16>,
start_at: Option<[u8; 32]>,
start_at_included: bool,
block_time_ms: Option<u64>,
contract: &'a DataContract,
document_type: DocumentTypeRef<'a>,
config: &DriveConfig,
) -> Result<Self, Error>
pub fn from_decomposed_values( where_clause: Value, order_by: Option<Value>, maybe_limit: Option<u16>, start_at: Option<[u8; 32]>, start_at_included: bool, block_time_ms: Option<u64>, contract: &'a DataContract, document_type: DocumentTypeRef<'a>, config: &DriveConfig, ) -> Result<Self, Error>
Converts a query Value to a DriveQuery.
Sourcepub fn from_sql_expr(
sql_string: &str,
contract: &'a DataContract,
config: Option<&DriveConfig>,
) -> Result<Self, Error>
pub fn from_sql_expr( sql_string: &str, contract: &'a DataContract, config: Option<&DriveConfig>, ) -> Result<Self, Error>
Converts a SQL expression to a DriveQuery.
Sourcepub fn to_cbor(&self) -> Result<Vec<u8>, Error>
pub fn to_cbor(&self) -> Result<Vec<u8>, Error>
Serialize drive query to CBOR format.
FIXME: The data contract is only referred as ID, and document type as its name. This can change in the future to include full data contract and document type.
Sourcepub fn start_at_document_path_and_key(
&self,
starts_at: &[u8; 32],
) -> (Vec<Vec<u8>>, Vec<u8>)
pub fn start_at_document_path_and_key( &self, starts_at: &[u8; 32], ) -> (Vec<Vec<u8>>, Vec<u8>)
Operations to construct a path query.
Sourcepub fn construct_path_query_operations(
&self,
drive: &Drive,
include_start_at_for_proof: bool,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<PathQuery, Error>
pub fn construct_path_query_operations( &self, drive: &Drive, include_start_at_for_proof: bool, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<PathQuery, Error>
Operations to construct a path query.
Sourcepub fn construct_path_query(
&self,
starts_at_document: Option<Document>,
platform_version: &PlatformVersion,
) -> Result<PathQuery, Error>
pub fn construct_path_query( &self, starts_at_document: Option<Document>, platform_version: &PlatformVersion, ) -> Result<PathQuery, Error>
Operations to construct a path query.
Sourcepub fn get_primary_key_path_query(
&self,
document_type_path: Vec<Vec<u8>>,
starts_at_document: Option<(Document, bool)>,
platform_version: &PlatformVersion,
) -> Result<PathQuery, Error>
pub fn get_primary_key_path_query( &self, document_type_path: Vec<Vec<u8>>, starts_at_document: Option<(Document, bool)>, platform_version: &PlatformVersion, ) -> Result<PathQuery, Error>
Returns a path query given a document type path and starting document.
Sourcepub fn find_best_index(
&self,
platform_version: &PlatformVersion,
) -> Result<&Index, Error>
pub fn find_best_index( &self, platform_version: &PlatformVersion, ) -> Result<&Index, Error>
Finds the best index for the query.
Sourcepub fn query_item_for_starts_at_key(
starts_at_key: Vec<u8>,
left_to_right: bool,
) -> QueryItem
pub fn query_item_for_starts_at_key( starts_at_key: Vec<u8>, left_to_right: bool, ) -> QueryItem
Returns a QueryItem given a start key and query direction.
Sourcepub fn get_non_primary_key_path_query(
&self,
document_type_path: Vec<Vec<u8>>,
starts_at_document: Option<(Document, bool)>,
platform_version: &PlatformVersion,
) -> Result<PathQuery, Error>
pub fn get_non_primary_key_path_query( &self, document_type_path: Vec<Vec<u8>>, starts_at_document: Option<(Document, bool)>, platform_version: &PlatformVersion, ) -> Result<PathQuery, Error>
Returns a path query for non-primary keys given a document type path and starting document.
Sourcepub fn execute_with_proof(
self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(Vec<u8>, u64), Error>
pub fn execute_with_proof( self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(Vec<u8>, u64), Error>
Executes a query with proof and returns the items and fee.
Sourcepub fn execute_with_proof_only_get_elements(
self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(RootHash, Vec<Vec<u8>>, u64), Error>
pub fn execute_with_proof_only_get_elements( self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(RootHash, Vec<Vec<u8>>, u64), Error>
Executes a query with proof and returns the root hash, items, and fee.
Sourcepub fn execute_raw_results_no_proof(
&self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(Vec<Vec<u8>>, u16, u64), Error>
pub fn execute_raw_results_no_proof( &self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(Vec<Vec<u8>>, u16, u64), Error>
Executes a query with no proof and returns the items, skipped items, and fee.
Sourceimpl DriveDocumentQuery<'_>
impl DriveDocumentQuery<'_>
Sourcepub fn verify_proof(
&self,
proof: &[u8],
platform_version: &PlatformVersion,
) -> Result<(RootHash, Vec<Document>), Error>
pub fn verify_proof( &self, proof: &[u8], platform_version: &PlatformVersion, ) -> Result<(RootHash, Vec<Document>), Error>
Verifies a proof for a collection of documents.
This function takes a byte slice representing the serialized proof, verifies it, and returns a tuple consisting of the root hash and a vector of deserialized documents.
Arguments
proof- A byte slice representing the proof to be verified.platform_version- The platform version against which to verify the proof.
Returns
A Result containing:
- A tuple with the root hash and a vector of deserialized
Documents if the proof is valid. - An
Errorvariant, in case the proof verification fails or a deserialization error occurs.
Errors
This function will return an Error variant if:
- The proof verification fails.
- A deserialization error occurs when parsing the serialized document(s).
Sourceimpl DriveDocumentQuery<'_>
impl DriveDocumentQuery<'_>
Sourcepub fn verify_proof_keep_serialized(
&self,
proof: &[u8],
platform_version: &PlatformVersion,
) -> Result<(RootHash, Vec<Vec<u8>>), Error>
pub fn verify_proof_keep_serialized( &self, proof: &[u8], platform_version: &PlatformVersion, ) -> Result<(RootHash, Vec<Vec<u8>>), Error>
Verifies the given proof and returns the root hash of the GroveDB tree and a vector of serialized documents if the verification is successful.
Arguments
proof- A byte slice representing the proof to be verified.platform_version- The platform version against which to verify the proof.
Returns
- On success, returns a tuple containing the root hash of the GroveDB tree and a vector of serialized documents.
- On failure, returns an Error.
Errors
This function will return an Error if:
- The start at document is not present in proof and it is expected to be.
- The path query fails to verify against the given proof.
- Converting the element into bytes fails.
Sourceimpl DriveDocumentQuery<'_>
impl DriveDocumentQuery<'_>
Sourcepub fn verify_start_at_document_in_proof(
&self,
proof: &[u8],
is_proof_subset: bool,
document_id: [u8; 32],
platform_version: &PlatformVersion,
) -> Result<(RootHash, Option<Document>), Error>
pub fn verify_start_at_document_in_proof( &self, proof: &[u8], is_proof_subset: bool, document_id: [u8; 32], platform_version: &PlatformVersion, ) -> Result<(RootHash, Option<Document>), Error>
Verifies if a document exists at the beginning of a proof, and returns the root hash and the optionally found document.
Arguments
proof- A byte slice containing the proof data.is_proof_subset- A boolean indicating whether the proof is a subset query or not.document_id- A byte_32 array, representing the ID of the document to start at.platform_version- The platform version against which to verify the proof.
Returns
A Result with a tuple containing:
- The root hash of the verified proof.
- An
Option<Document>containing the found document if available.
Errors
This function returns an Error in the following cases:
- If the proof is corrupted (wrong path, wrong key, etc.).
- If the provided proof has an incorrect number of elements.