pub struct VotePollsByEndDateDriveQuery {
pub start_time: Option<(TimestampMillis, TimestampIncluded)>,
pub end_time: Option<(TimestampMillis, TimestampIncluded)>,
pub limit: Option<u16>,
pub offset: Option<u16>,
pub order_ascending: bool,
}Expand description
Vote Poll Drive Query struct
Fields
start_time: Option<(TimestampMillis, TimestampIncluded)>What is the start time we are asking for
end_time: Option<(TimestampMillis, TimestampIncluded)>What vote poll are we asking for?
limit: Option<u16>Limit
offset: Option<u16>Offset
order_ascending: boolAscending
Implementations
Sourceimpl VotePollsByEndDateDriveQuery
impl VotePollsByEndDateDriveQuery
Sourcepub fn path_query_for_end_time_included(
end_time: TimestampMillis,
limit: u16,
) -> PathQuery
pub fn path_query_for_end_time_included( end_time: TimestampMillis, limit: u16, ) -> PathQuery
Get the path query for an abci query that gets vote polls until an end time
Sourcepub fn path_query_for_single_end_time(
end_time: TimestampMillis,
limit: u16,
) -> PathQuery
pub fn path_query_for_single_end_time( end_time: TimestampMillis, limit: u16, ) -> PathQuery
Get the path query for an abci query that gets vote polls at an the end time
Sourcepub fn execute_no_proof_for_specialized_end_time_query(
end_time: TimestampMillis,
limit: u16,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<BTreeMap<TimestampMillis, Vec<VotePoll>>, Error>
pub fn execute_no_proof_for_specialized_end_time_query( end_time: TimestampMillis, limit: u16, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<BTreeMap<TimestampMillis, Vec<VotePoll>>, Error>
Executes a special query with no proof to get contested document resource vote polls. This is meant for platform abci to get votes that have finished
Sourcepub fn execute_no_proof_for_specialized_end_time_query_only_check_end_time(
end_time: TimestampMillis,
limit: u16,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<Vec<VotePoll>, Error>
pub fn execute_no_proof_for_specialized_end_time_query_only_check_end_time( end_time: TimestampMillis, limit: u16, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<Vec<VotePoll>, Error>
Executes a special query with no proof to get contested document resource vote polls. This is meant for platform abci to get votes that have finished
Sourcepub fn construct_path_query(&self) -> PathQuery
pub fn construct_path_query(&self) -> PathQuery
Operations to construct a path query.
Sourcepub fn execute_with_proof(
self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(Vec<u8>, u64), Error>
pub fn execute_with_proof( self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(Vec<u8>, u64), Error>
Executes a query with proof and returns the items and fee.
Sourcepub fn execute_no_proof_with_cost(
&self,
drive: &Drive,
block_info: Option<BlockInfo>,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<(BTreeMap<TimestampMillis, Vec<VotePoll>>, Credits), Error>
pub fn execute_no_proof_with_cost( &self, drive: &Drive, block_info: Option<BlockInfo>, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<(BTreeMap<TimestampMillis, Vec<VotePoll>>, Credits), Error>
Executes a query with no proof and returns the items, skipped items, and fee.
Sourcepub fn execute_no_proof(
&self,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<BTreeMap<TimestampMillis, Vec<VotePoll>>, Error>
pub fn execute_no_proof( &self, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<BTreeMap<TimestampMillis, Vec<VotePoll>>, Error>
Executes an internal query with no proof and returns the values and skipped items.
Sourcepub fn execute_no_proof_keep_serialized(
&self,
drive: &Drive,
transaction: TransactionArg<'_, '_>,
drive_operations: &mut Vec<LowLevelDriveOperation>,
platform_version: &PlatformVersion,
) -> Result<BTreeMap<TimestampMillis, Vec<Vec<u8>>>, Error>
pub fn execute_no_proof_keep_serialized( &self, drive: &Drive, transaction: TransactionArg<'_, '_>, drive_operations: &mut Vec<LowLevelDriveOperation>, platform_version: &PlatformVersion, ) -> Result<BTreeMap<TimestampMillis, Vec<Vec<u8>>>, Error>
Executes an internal query with no proof and returns the values and skipped items.
Sourceimpl VotePollsByEndDateDriveQuery
impl VotePollsByEndDateDriveQuery
Sourcepub fn verify_vote_polls_by_end_date_proof<I>(
&self,
proof: &[u8],
platform_version: &PlatformVersion,
) -> Result<(RootHash, I), Error>
pub fn verify_vote_polls_by_end_date_proof<I>( &self, proof: &[u8], platform_version: &PlatformVersion, ) -> Result<(RootHash, I), Error>
Verifies the serialized proof for a vote poll based on the end date.
This function analyzes a byte slice which contains the serialized proof, performs verification, and returns the results, which include the root hash of the proof and a structured collection of the contests.
Arguments
proof- A byte slice of the serialized proof that needs to be verified.platform_version- The version of the platform which defines how the proof should be verified.
Returns
A Result which is either:
Ok((RootHash, I))if the proof is verified successfully, whereIis a collection of items with keys as timestamps (in milliseconds since the epoch) and values as vectors ofContestedDocumentResourceVotePollobjects, representing voting polls ending at those times. The collection type is flexible and determined by the generic parameterI.Err(Error)if there is a failure in proof verification or during the deserialization of documents.
Errors
Returns an Error if:
- Proof verification fails due to invalid data or signature issues.
- Deserialization error occurs due to malformed data or incompatible types in the document(s).