pub enum TokenTransitionAction {
BurnAction(TokenBurnTransitionAction),
MintAction(TokenMintTransitionAction),
TransferAction(TokenTransferTransitionAction),
FreezeAction(TokenFreezeTransitionAction),
UnfreezeAction(TokenUnfreezeTransitionAction),
ClaimAction(TokenClaimTransitionAction),
EmergencyActionAction(TokenEmergencyActionTransitionAction),
DestroyFrozenFundsAction(TokenDestroyFrozenFundsTransitionAction),
ConfigUpdateAction(TokenConfigUpdateTransitionAction),
DirectPurchaseAction(TokenDirectPurchaseTransitionAction),
SetPriceForDirectPurchaseAction(TokenSetPriceForDirectPurchaseTransitionAction),
}Expand description
token action
Variants
BurnAction(TokenBurnTransitionAction)
burn
MintAction(TokenMintTransitionAction)
issuance
TransferAction(TokenTransferTransitionAction)
transfer
FreezeAction(TokenFreezeTransitionAction)
freeze
UnfreezeAction(TokenUnfreezeTransitionAction)
unfreeze
ClaimAction(TokenClaimTransitionAction)
release
EmergencyActionAction(TokenEmergencyActionTransitionAction)
emergency action
DestroyFrozenFundsAction(TokenDestroyFrozenFundsTransitionAction)
destroy frozen funds action
ConfigUpdateAction(TokenConfigUpdateTransitionAction)
update the token configuration
DirectPurchaseAction(TokenDirectPurchaseTransitionAction)
purchases the token from the contract owner
SetPriceForDirectPurchaseAction(TokenSetPriceForDirectPurchaseTransitionAction)
sets the price for direct purchase of the token
Implementations
Sourceimpl TokenTransitionAction
impl TokenTransitionAction
Sourcepub fn associated_token_event(&self) -> TokenEvent
pub fn associated_token_event(&self) -> TokenEvent
Gets the associated token event for the transition action
Sourceimpl TokenTransitionAction
impl TokenTransitionAction
Sourcepub fn base(&self) -> &TokenBaseTransitionAction
pub fn base(&self) -> &TokenBaseTransitionAction
Returns a reference to the base token transition action if available
Sourcepub fn base_owned(self) -> TokenBaseTransitionAction
pub fn base_owned(self) -> TokenBaseTransitionAction
Consumes self and returns the base token transition action if available
Sourcepub fn historical_document_type_name(&self) -> &str
pub fn historical_document_type_name(&self) -> &str
Historical document type name for the token history contract
Sourcepub fn historical_document_type<'a>(
&self,
token_history_contract: &'a DataContract,
) -> Result<DocumentTypeRef<'a>, ProtocolError>
pub fn historical_document_type<'a>( &self, token_history_contract: &'a DataContract, ) -> Result<DocumentTypeRef<'a>, ProtocolError>
Historical document type for the token history contract
Sourcepub fn historical_document_id(&self, owner_id: Identifier) -> Identifier
pub fn historical_document_id(&self, owner_id: Identifier) -> Identifier
Historical document id
Sourcepub fn build_historical_document(
&self,
token_id: Identifier,
owner_id: Identifier,
owner_nonce: IdentityNonce,
block_info: &BlockInfo,
platform_version: &PlatformVersion,
) -> Result<Document, Error>
pub fn build_historical_document( &self, token_id: Identifier, owner_id: Identifier, owner_nonce: IdentityNonce, block_info: &BlockInfo, platform_version: &PlatformVersion, ) -> Result<Document, Error>
Historical document
Sourcepub fn keeps_history(&self) -> Result<bool, Error>
pub fn keeps_history(&self) -> Result<bool, Error>
Do we keep history for this action