BatchTransitionAction

Enum BatchTransitionAction 

pub enum BatchTransitionAction {
    V0(BatchTransitionActionV0),
}
documents batch transition action

Variants

Implementations

Source

impl BatchTransitionAction

pub fn owner_id(&self) -> Identifier

owner id

pub fn transitions(&self) -> &Vec<BatchedTransitionAction>

transitions

pub fn transitions_mut(&mut self) -> &mut Vec<BatchedTransitionAction>

transitions

pub fn transitions_take(&mut self) -> Vec<BatchedTransitionAction>

transitions

pub fn transitions_owned(self) -> Vec<BatchedTransitionAction>

transitions owned

pub fn set_transitions(&mut self, transitions: Vec<BatchedTransitionAction>)

set transitions

pub fn user_fee_increase(&self) -> UserFeeIncrease

fee multiplier

Source

impl BatchTransitionAction

pub fn all_used_balances(&self) -> Result<Option<Credits>, ProtocolError>

The sum of all purchases amount and all conflicting index collateral voting funds

pub fn all_purchases_amount(&self) -> Result<Option<Credits>, ProtocolError>

The sum of all purchases amounts for all purchase transitions in the batch

pub fn all_conflicting_index_collateral_voting_funds( &self, ) -> Result<Option<Credits>, ProtocolError>

The sum of all conflicting index collateral voting funds for all document create transitions in the batch

pub fn combined_security_level_requirement( &self, ) -> Result<Vec<SecurityLevel>, ProtocolError>

Determines the security level requirements for the batch transition action.

This method performs the following steps:

  1. Retrieves all document types associated with the state transitions (STs) in the batch.
  2. For each document type, fetches its schema to determine its security level requirement.
    • If the schema specifies a security level, that is used.
    • Otherwise, a default security level is used.

The method then determines the highest security level (which corresponds to the lowest integer value of the SecurityLevel enum) across all documents affected by the state transitions. This highest level becomes the signature requirement for the entire batch transition action.

Returns
  • Returns a Result containing a Vec<SecurityLevel> which is the list of security levels required for the batch transition action.
  • Returns an Err of type ProtocolError if any error occurs during the process.
Examples
// Assuming `batch_transition_action` is an instance of `DocumentsBatchTransitionAction`
let required_levels = batch_transition_action.contract_based_security_level_requirement()?;