pub enum BatchTransitionAction {
V0(BatchTransitionActionV0),
}Expand description
documents batch transition action
Variants
V0(BatchTransitionActionV0)
v0
Implementations
Sourceimpl BatchTransitionAction
impl BatchTransitionAction
Sourcepub fn owner_id(&self) -> Identifier
pub fn owner_id(&self) -> Identifier
owner id
Sourcepub fn transitions(&self) -> &Vec<BatchedTransitionAction>
pub fn transitions(&self) -> &Vec<BatchedTransitionAction>
transitions
Sourcepub fn transitions_mut(&mut self) -> &mut Vec<BatchedTransitionAction>
pub fn transitions_mut(&mut self) -> &mut Vec<BatchedTransitionAction>
transitions
Sourcepub fn transitions_take(&mut self) -> Vec<BatchedTransitionAction>
pub fn transitions_take(&mut self) -> Vec<BatchedTransitionAction>
transitions
Sourcepub fn transitions_owned(self) -> Vec<BatchedTransitionAction>
pub fn transitions_owned(self) -> Vec<BatchedTransitionAction>
transitions owned
Sourcepub fn set_transitions(&mut self, transitions: Vec<BatchedTransitionAction>)
pub fn set_transitions(&mut self, transitions: Vec<BatchedTransitionAction>)
set transitions
Sourcepub fn user_fee_increase(&self) -> UserFeeIncrease
pub fn user_fee_increase(&self) -> UserFeeIncrease
fee multiplier
Sourceimpl BatchTransitionAction
impl BatchTransitionAction
Sourcepub fn all_used_balances(&self) -> Result<Option<Credits>, ProtocolError>
pub fn all_used_balances(&self) -> Result<Option<Credits>, ProtocolError>
The sum of all purchases amount and all conflicting index collateral voting funds
Sourcepub fn all_purchases_amount(&self) -> Result<Option<Credits>, ProtocolError>
pub fn all_purchases_amount(&self) -> Result<Option<Credits>, ProtocolError>
The sum of all purchases amounts for all purchase transitions in the batch
Sourcepub fn all_conflicting_index_collateral_voting_funds(
&self,
) -> Result<Option<Credits>, ProtocolError>
pub fn all_conflicting_index_collateral_voting_funds( &self, ) -> Result<Option<Credits>, ProtocolError>
The sum of all conflicting index collateral voting funds for all document create transitions in the batch
Sourcepub fn combined_security_level_requirement(
&self,
) -> Result<Vec<SecurityLevel>, ProtocolError>
pub fn combined_security_level_requirement( &self, ) -> Result<Vec<SecurityLevel>, ProtocolError>
Determines the security level requirements for the batch transition action.
This method performs the following steps:
- Retrieves all document types associated with the state transitions (STs) in the batch.
- For each document type, fetches its schema to determine its security level requirement.
- If the schema specifies a security level, that is used.
- Otherwise, a default security level is used.
The method then determines the highest security level (which corresponds to the lowest
integer value of the SecurityLevel enum) across all documents affected by the state transitions.
This highest level becomes the signature requirement for the entire batch transition action.
Returns
- Returns a
Resultcontaining aVec<SecurityLevel>which is the list of security levels required for the batch transition action. - Returns an
Errof typeProtocolErrorif any error occurs during the process.
Examples
// Assuming `batch_transition_action` is an instance of `DocumentsBatchTransitionAction`
let required_levels = batch_transition_action.contract_based_security_level_requirement()?;Trait Implementations
Sourceimpl Clone for BatchTransitionAction
impl Clone for BatchTransitionAction
Sourcefn clone(&self) -> BatchTransitionAction
fn clone(&self) -> BatchTransitionAction
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BatchTransitionAction
impl Debug for BatchTransitionAction
Sourceimpl DriveHighLevelOperationConverter for BatchTransitionAction
impl DriveHighLevelOperationConverter for BatchTransitionAction
Sourcefn into_high_level_drive_operations<'b>(
self,
epoch: &Epoch,
platform_version: &PlatformVersion,
) -> Result<Vec<DriveOperation<'b>>, Error>
fn into_high_level_drive_operations<'b>( self, epoch: &Epoch, platform_version: &PlatformVersion, ) -> Result<Vec<DriveOperation<'b>>, Error>
Sourceimpl From<BatchTransitionAction> for StateTransitionAction
impl From<BatchTransitionAction> for StateTransitionAction
Sourcefn from(value: BatchTransitionAction) -> Self
fn from(value: BatchTransitionAction) -> Self
Sourceimpl From<BatchTransitionActionV0> for BatchTransitionAction
impl From<BatchTransitionActionV0> for BatchTransitionAction
Sourcefn from(value: BatchTransitionActionV0) -> Self
fn from(value: BatchTransitionActionV0) -> Self