pub trait DriveLowLevelOperationConverter {
// Required method
fn into_low_level_drive_operations(
self,
drive: &Drive,
estimated_costs_only_with_layer_info: &mut Option<HashMap<KeyInfoPath, EstimatedLayerInformation>>,
block_info: &BlockInfo,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<Vec<LowLevelDriveOperation>, Error>;
}Expand description
A converter that will get Drive Operations from High Level Operations
Required Methods
Sourcefn into_low_level_drive_operations(
self,
drive: &Drive,
estimated_costs_only_with_layer_info: &mut Option<HashMap<KeyInfoPath, EstimatedLayerInformation>>,
block_info: &BlockInfo,
transaction: TransactionArg<'_, '_>,
platform_version: &PlatformVersion,
) -> Result<Vec<LowLevelDriveOperation>, Error>
fn into_low_level_drive_operations( self, drive: &Drive, estimated_costs_only_with_layer_info: &mut Option<HashMap<KeyInfoPath, EstimatedLayerInformation>>, block_info: &BlockInfo, transaction: TransactionArg<'_, '_>, platform_version: &PlatformVersion, ) -> Result<Vec<LowLevelDriveOperation>, Error>
This will get a list of atomic drive operations from a high level operations