pub fn setup_drive(drive_config: Option<DriveConfig>) -> DriveExpand description
Sets up Drive using a temporary directory and the optionally given Drive configuration settings.
The returned Drive owns the directory, which is removed when the Drive is dropped.