pub fn setup_drive(drive_config: Option<DriveConfig>) -> DriveExpand description
Sets up Drive using a temporary directory and the optionally given Drive configuration settings.
pub fn setup_drive(drive_config: Option<DriveConfig>) -> DriveSets up Drive using a temporary directory and the optionally given Drive configuration settings.